AvatarData class

AvatarData data class is used for create image avatar response handle avatarDataId that contain String value of Avatar Image ID Status is contain Integer value type ,accountId , id is contain String value version , order ,v is contain integer value FrontendConfig is contains object value AvatarConfig is contains object value createdAt, updatedAt is contains DateTime value

Constructors

AvatarData({String? avatarDataId, int? status, String? type, int? version, int? order, String? accountId, FrontendConfig? frontendConfig, AvatarConfig? avatarConfig, List? variants, String? id, DateTime? createdAt, DateTime? updatedAt, int? v})
this is constructor of AvatarData class
AvatarData.fromJson(Map<String, dynamic> json)
factory

Properties

accountId ↔ String?
getter/setter pair
avatarConfig ↔ AvatarConfig?
getter/setter pair
avatarDataId ↔ String?
getter/setter pair
createdAt ↔ DateTime?
getter/setter pair
frontendConfig ↔ FrontendConfig?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
order ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ int?
getter/setter pair
type ↔ String?
getter/setter pair
updatedAt ↔ DateTime?
getter/setter pair
v ↔ int?
getter/setter pair
variants ↔ List?
getter/setter pair
version ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited