FrontendConfig class

AvatarConfig data class that contains gender , thumbnail ,canvas ,tilt ,faceBbox values tilt,faceBbox is contains object value gender , thumbnail ,canvas contains String values

Constructors

FrontendConfig({String? gender, String? thumbnail, String? canvas, Tilt? tilt, FaceBbox? faceBbox})
This is constructor of class FrontendConfig tilt,faceBbox is contains object value gender , thumbnail ,canvas contains String values
FrontendConfig.fromJson(Map<String, dynamic> json)
tilt,faceBbox is contains object value gender , thumbnail ,canvas contains String values
factory

Properties

canvas ↔ String?
getter/setter pair
faceBbox ↔ FaceBbox?
getter/setter pair
gender ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnail ↔ String?
getter/setter pair
tilt ↔ Tilt?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited