Avatar class

Avatar data class is object class id that contain String value id of avatar image version is contain upadted or latest version name ,gender,canvas is contains String values

Constructors

Avatar({String? id, int? version, String? name, String? gender, String? canvas})
This is constructor of Avatar id that contain String value id of avatar image version is contain upadted or latest version name ,gender,canvas is contains String values
Avatar.fromJson(Map<String, dynamic> json)
id that contain String value id of avatar image version is contain upadted or latest version name ,gender,canvas is contains String values
factory

Properties

canvas ↔ String?
getter/setter pair
gender ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
name ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
id that contain String value id of avatar image version is contain upadted or latest version name ,gender,canvas is contains String values
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited