Canvas class

Canvas data class is object class objects is a list of items background is contain background color version is contains String values

Constructors

Canvas({List<Object>? objects, String? background, String? version})
This is constructor of Canvas objects is a list of items background is contain background color version is contains String values
Canvas.fromJson(Map<String, dynamic> json)
objects is a list of items background is contain background color version is contains String values
factory

Properties

background ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
objects ↔ List<Object>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
objects is a list of items background is contain background color version is contains String values
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited