CreateVideoAvatarData class

CreateVideoAvatarData data class is used for handle response create video from avatar id that contain String value of Avatar video ID name is contain String value video name url , sourceId, status, userId, accountId is contain String Values deleted , verified, public is contain bool Values slides is contains a list of items tags is contains a list of items createdAt , updatedAt is contain DateTime Values

Constructors

CreateVideoAvatarData({String? id, String? name, List<Slide>? slides, List<String>? tags, String? url, String? sourceId, bool? deleted, String? status, bool? verified, bool? public, String? userId, String? accountId, DateTime? createdAt, DateTime? updatedAt})
This is constructor of CreateVideoAvatarData id that contain String value of Avatar video ID name is contain String value video name url , sourceId, status, userId, accountId is contain String Values deleted , verified, public is contain bool Values slides is contains a list of items tags is contains a list of items createdAt , updatedAt is contain DateTime Values
CreateVideoAvatarData.fromJson(Map<String, dynamic> json)
id that contain String value of Avatar video ID name is contain String value video name url , sourceId, status, userId, accountId is contain String Values deleted , verified, public is contain bool Values slides is contains a list of items tags is contains a list of items createdAt , updatedAt is contain DateTime Values
factory

Properties

accountId ↔ String?
getter/setter pair
createdAt ↔ DateTime?
getter/setter pair
deleted ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
name ↔ String?
getter/setter pair
public ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slides ↔ List<Slide>?
getter/setter pair
sourceId ↔ String?
getter/setter pair
status ↔ String?
getter/setter pair
tags ↔ List<String>?
getter/setter pair
updatedAt ↔ DateTime?
getter/setter pair
url ↔ String?
getter/setter pair
userId ↔ String?
getter/setter pair
verified ↔ bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
id that contain String value of Avatar video ID name is contain String value video name url , sourceId, status, userId, accountId is contain String Values deleted , verified, public is contain bool Values slides is contains a list of items tags is contains a list of items createdAt , updatedAt is contain DateTime Values
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited