Object class

Avatar data class is object class type that contain String value type of avatar image version is contain upadted or latest version left,scaleX,scaleY is double value used to alignment of image fill, src, avatarType contains string value animation Contains object values

Constructors

Object({String? type, int? version, double? left, int? top, String? fill, double? scaleX, double? scaleY, String? src, String? avatarType, Animation? animation})
This is constructor of Object type that contain String value type of avatar image version is contain upadted or latest version left,scaleX,scaleY is double value used to alignment of image fill, src, avatarType contains string value animation Contains object values
Object.fromJson(Map<String, dynamic> json)
type that contain String value type of avatar image version is contain upadted or latest version left,scaleX,scaleY is double value used to alignment of image fill, src, avatarType contains string value animation Contains object values
factory

Properties

animation ↔ Animation?
getter/setter pair
avatarType ↔ String?
getter/setter pair
fill ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
left ↔ double?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaleX ↔ double?
getter/setter pair
scaleY ↔ double?
getter/setter pair
src ↔ String?
getter/setter pair
top ↔ int?
getter/setter pair
type ↔ String?
getter/setter pair
version ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
type that contain String value type of avatar image version is contain upadted or latest version left,scaleX,scaleY is double value used to alignment of image fill, src, avatarType contains string value animation Contains object values
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited