Slide class

Slide data class is object class id that contain int value animation , language, speech, voice, voiceType, voiceProvider is contain String Values Canvas ,Avatar is contains a object values tags is contains a list of items

Constructors

Slide({int? id, Canvas? canvas, Avatar? avatar, String? animation, String? language, String? speech, String? voice, String? voiceType, String? voiceProvider})
This is constructor of Slide id that contain int value animation , language, speech, voice, voiceType, voiceProvider is contain String Values Canvas ,Avatar is contains a object values tags is contains a list of items
Slide.fromJson(Map<String, dynamic> json)
id that contain int value animation , language, speech, voice, voiceType, voiceProvider is contain String Values Canvas ,Avatar is contains a object values tags is contains a list of items
factory

Properties

animation ↔ String?
getter/setter pair
avatar ↔ Avatar?
getter/setter pair
canvas ↔ Canvas?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
getter/setter pair
language ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
speech ↔ String?
getter/setter pair
voice ↔ String?
getter/setter pair
voiceProvider ↔ String?
getter/setter pair
voiceType ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited